package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(/@`````````0```````
M`*%0``````!``#@`"`!``!8`%0````8````$`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````&``````````8``````````$````!
M````!0```````````````````````````````````````)<@````````ER``
M```````0``````$````&````````F_````````"K\````````*OP````````
M!(@````````4Z````````!```````@````8```````"<$````````*P0````
M````K!`````````!H`````````&@``````````AD=.50````!````````)$T
M````````D30```````"1-`````````#4`````````-0`````````!&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````";\````````*OP````````J_`````````$
M$`````````00``````````$O;&EB+VQD+6UU<VPM<S,Y,'@N<V\N,0`````1
M````1@````0````(@`1`!0`0$""$`(:`!!``*`D$``D``"&""`($ND$8@(@`
M````````1@```$H```!.````3P```%4```!6````5P````````!9````6@``
M``````!;````7````%X``````````'R:?VH.[]/J+4?>SA_?Q6^VF\4N#O&-
MN'S49-0.Y/\A'%AQV6!LH?HL/^7";XL!LH?7^D(!QD?B?)+CN](\PU5FS*]G
MTW`'B.S514/MVV(SS"6,%9N<J7\*`J?@4)X::TG[X*,`````````````````
M`````````````````````P``!P```````!>P```````````````!$@``````
M```````````````````````)$0````````````````````````````&N$0``
M``````````````````````````%*$@`````````````````````````````0
M$@````````````````````````````&'$@``````````````````````````
M```8$@`````````````````````````````?$@``````````````````````
M``````&[$@````````````````````````````&3$@``````````````````
M```````````H(`````````````````````````````+*(0``````````````
M``````````````!`$@````````````````````````````!&$@``````````
M``````````````````*7$@````````````````````````````*($@``````
M``````````````````````'A$@````````````````````````````!-$@``
M``````````````````````````)G$@````````````````````````````!4
M$@````````````````````````````!<$@``````````````````````````
M``)0$@````````````````````````````!D$@``````````````````````
M``````!J$@````````````````````````````!S(```````````````````
M``````````*!$@````````````````````````````"/$@``````````````
M``````````````"4$@````````````````````````````',$0``````````
M``````````````````)N$@````````````````````````````(.$@``````
M``````````````````````";$@````````````````````````````(`$@``
M``````````````````````````,.$@````````````````````````````+)
M$0````````````````````````````(R$@``````````````````````````
M``*V$@````````````````````````````++$0``````````````````````
M``````"B$@````````````````````````````*N$@``````````````````
M``````````%8$@````````````````````````````"K(@``````````````
M``````````````"Z(`````````````````````````````#0$@``````````
M``````````````````)Y$@````````````````````````````(>$@``````
M``````````````````````#5$@````````````````````````````#;(```
M``````````````````````````);$@````````````````````````````#U
M$@````````````````````````````%X$@``````````````````````````
M``#Z$@````````````````````````````)`$@``````````````````````
M``````%G$@````````````````````````````$`$@``````````````````
M``````````$1$@````````````````````````````'<$@``````````````
M``````````````!E$@````````````````````````````'M$@``````````
M``````````````````(G$@````````````````````````````*G$@``````
M``````````````````````$7$@````````````````````````````*?$@``
M``````````````````````````$K$@````````````````````````````'7
M$@````````````````````````````$R$@``````````````````````````
M``+((0````````````````````````````%#$@``````````````````````
M``````+#$@``"0```````![X`````````?P```&H$@``"@```````%*(````
M``````(```-0$@``"0```````#!0````````!D(```/\$@``"0```````#D@
M`````````&@```,M$@``"0```````"I(``````````8```.Z$@``!P``````
M`!>P``````````(```-S$@``"0```````#:8`````````H0```/@$@``"0``
M`````"I0`````````=8```.K$```$P```````+!X``````````````,^$@``
M"0```````"^@`````````*P```-=$@``"0```````"B@`````````#P```-E
M$@``"0```````"\``````````&X```.)$@``"0```````$_(`````````4X`
M``.>$@``"0```````"PH`````````"(```/W$```$P```````,#8````````
M``````+S$@``"0```````"$H`````````#P```/`$@``"0```````"Q0````
M`````2(```.4$0``$@```````+!P``````````@```/9$```$@```````+!X
M``````````````.P$@``"0```````"#X``````````````.W$@``"0``````
M`$]8`````````&P```+\$@``"0```````"]P`````````"P```,7$@``"0``
M`````"E``````````00```/M$@``"0```````%$8`````````18```/,$@``
M"0```````"UX`````````8(`;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E
M<W,`<VYP<FEN=&8`7U]D97)E9VES=&5R7V9R86UE7VEN9F\`;'-E96L`9V5T
M<&ED`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``;'-T870`8VQO<V5D:7(`7TE4
M35]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T<F-H<@!R
M96%D;&EN:P!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`
M97AI=`!C;&]S90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD
M:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC
M`&UE;6-P>0!?7W-T86-K7V-H:U]F86EL`&=E='5I9`!097)L7W-Y<U]T97)M
M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`7V9I;FD`4$Q?
M9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R
M964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T
M<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D
M97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S
M>7-M86QL;V,`<&5R;%]A;&QO8P!F<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T
M9F]R:P!R96%D9&ER`'-P<FEN=&8`<W1R=&]K`'-T<FYC<'D`7U]L:6)C7W-T
M87)T7VUA:6X`7U]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"US,SDP
M>"YS;RXQ`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C=7)R96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U
M<%]L:6)P871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`
M6%-?26YT97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A
M<E]B87-E;F%M90!?7V)S<U]S=&%R=`!S:&%?:6YI=`!P87)?9&ER;F%M90!P
M87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD<')O9P!S:&%?9FEN86P`7V5N
M9`!P87)?8VQE86YU<``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210``
M`````````*^(``````````P````````>^````````*^@``````````P`````
M``!2B````````*^X``````````P````````7L````````+````````````P`
M``````"P`````````+`0``````````P```````!2J@```````+`8````````
M``P```````!2L````````+`H``````````P```````!2L@```````+`P````
M``````P```````!2M@```````+`X``````````P```````!2O@```````+!`
M``````````P```````!3*@```````+!(``````````P```````!2Q@``````
M`+!8``````````P```````!2R@```````+!@``````````P```````!2T```
M`````+!P``````````P```````!5A@```````*^0`````P````H`````````
M`````````*^8````!`````H``````````````````*^H````#`````H`````
M`````````````*^P````&@````H``````````````````*_`````'@````H`
M`````````````````*_(````)P````H``````````````````*_0````*P``
M``H``````````````````*_8````+`````H``````````````````*_@````
M,0````H``````````````````*_H````-@````H``````````````````*_P
M````-P````H``````````````````*_X````/`````H`````````````````
M`*W(`````@````L``````````````````*W0````!0````L`````````````
M`````*W8````!@````L``````````````````*W@````!P````L`````````
M`````````*WH````"`````L``````````````````*WP````"0````L`````
M`````````````*WX````"@````L``````````````````*X`````"P````L`
M`````````````````*X(````#`````L``````````````````*X0````#@``
M``L``````````````````*X8````#P````L``````````````````*X@````
M$`````L``````````````````*XH````$0````L``````````````````*XP
M````$@````L``````````````````*XX````$P````L`````````````````
M`*Y`````%`````L``````````````````*Y(````%0````L`````````````
M`````*Y0````%@````L``````````````````*Y8````%P````L`````````
M`````````*Y@````&`````L``````````````````*YH````&0````L`````
M`````````````*YP````&P````L``````````````````*YX````'`````L`
M`````````````````*Z`````'0````L``````````````````*Z(````'P``
M``L``````````````````*Z0````(`````L``````````````````*Z8````
M(0````L``````````````````*Z@````(@````L``````````````````*ZH
M````(P````L``````````````````*ZP````)0````L`````````````````
M`*ZX````)@````L``````````````````*[`````*`````L`````````````
M`````*[(````*0````L``````````````````*[0````*@````L`````````
M`````````*[8````*P````L``````````````````*[@````+`````L`````
M`````````````*[H````+0````L``````````````````*[P````+@````L`
M`````````````````*[X````+P````L``````````````````*\`````,```
M``L``````````````````*\(````,@````L``````````````````*\0````
M,P````L``````````````````*\8````-`````L``````````````````*\@
M````-0````L``````````````````*\H````.`````L`````````````````
M`*\P````.0````L``````````````````*\X````.@````L`````````````
M`````*]`````.P````L``````````````````*](````/0````L`````````
M`````````*]0````/@````L``````````````````*]8````/P````L`````
M`````````````*]@````0`````L``````````````````*]H````00````L`
M`````````````````*]P````0@````L``````````````````*]X````0P``
M``L``````````````````*^`````10````L``````````.OO\'``)+D$``^G
M^_]@XP#P```DP.4```5RP.4``!TSZ^_Q$``$!_[C$/`X`"3`$```2NG2!_`P
M$`CC$!`0``0'\0<`!P`'`,`0``!*Z.,0$```!`?Q#1#C$!`,`!3`]/___^4`
M````P!```$K<XQ`0```$!_$-$.,0$`P`%,#T____U0```!C`$```2M#C$!``
M``0'\0T0XQ`0#``4P/3____%````,,`0``!*Q.,0$```!`?Q#1#C$!`,`!3`
M]/___[4```!(P!```$JXXQ`0```$!_$-$.,0$`P`%,#T____I0```&#`$```
M2JSC$!````0'\0T0XQ`0#``4P/3___^5````>,`0``!*H.,0$```!`?Q#1#C
M$!`,`!3`]/___X4```"0P!```$J4XQ`0```$!_$-$.,0$`P`%,#T____=0``
M`*C`$```2HCC$!````0'\0T0XQ`0#``4P/3___]E````P,`0``!*?.,0$```
M!`?Q#1#C$!`,`!3`]/___U4```#8P!```$IPXQ`0```$!_$-$.,0$`P`%,#T
M____10```/#`$```2F3C$!````0'\0T0XQ`0#``4P/3___\U```!",`0``!*
M6.,0$```!`?Q#1#C$!`,`!3`]/___R4```$@P!```$I,XQ`0```$!_$-$.,0
M$`P`%,#T____%0```3C`$```2D#C$!````0'\0T0XQ`0#``4P/3___\%```!
M4,`0``!*-.,0$```!`?Q#1#C$!`,`!3`]/___O4```%HP!```$HHXQ`0```$
M!_$-$.,0$`P`%,#T___^Y0```8#`$```2ASC$!````0'\0T0XQ`0#``4P/3_
M__[5```!F,`0``!*$.,0$```!`?Q#1#C$!`,`!3`]/___L4```&PP!```$H$
MXQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`$```2?CC$!````0'\0T0XQ`0
M#``4P/3___ZE```!X,`0``!)[.,0$```!`?Q#1#C$!`,`!3`]/___I4```'X
MP!```$G@XQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`$```2=3C$!````0'
M\0T0XQ`0#``4P/3___YU```"*,`0``!)R.,0$```!`?Q#1#C$!`,`!3`]/__
M_F4```)`P!```$F\XQ`0```$!_$-$.,0$`P`%,#T___^50```EC`$```2;#C
M$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0``!)I.,0$```!`?Q#1#C$!`,
M`!3`]/___C4```*(P!```$F8XQ`0```$!_$-$.,0$`P`%,#T___^)0```J#`
M$```28SC$!````0'\0T0XQ`0#``4P/3___X5```"N,`0``!)@.,0$```!`?Q
M#1#C$!`,`!3`]/___@4```+0P!```$ETXQ`0```$!_$-$.,0$`P`%,#T___]
M]0```NC`$```26CC$!````0'\0T0XQ`0#``4P/3___WE```#`,`0``!)7.,0
M$```!`?Q#1#C$!`,`!3`]/___=4```,8P!```$E0XQ`0```$!_$-$.,0$`P`
M%,#T___]Q0```S#`$```243C$!````0'\0T0XQ`0#``4P/3___VU```#2,`0
M``!)..,0$```!`?Q#1#C$!`,`!3`]/___:4```-@P!```$DLXQ`0```$!_$-
M$.,0$`P`%,#T___]E0```WC`$```22#C$!````0'\0T0XQ`0#``4P/3___V%
M```#D,`0``!)%.,0$```!`?Q#1#C$!`,`!3`]/___74```.HP!```$D(XQ`0
M```$!_$-$.,0$`P`%,#T___]90```\#`$```2/SC$!````0'\0T0XQ`0#``4
MP/3___U5```#V,`0``!(\.,0$```!`?Q#1#C$!`,`!3`]/___44```/PP!``
M`$CDXQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`$```2-CC$!````0'\0T0
MXQ`0#``4P/3___TE```$(,`0``!(S.,0$```!`?Q#1#C$!`,`!3`]/___14`
M``0XP!```$C`XQ`0```$!_$-$.,0$`P`%,#T___]!0``!%#`$```2+3C$!``
M``0'\0T0XQ`0#``4P/3___SU```$:,`0``!(J.,0$```!`?Q#1#C$!`,`!3`
M]/___.4```2`P!```$B<XQ`0```$!_$-$.,0$`P`%,#T___\U0``!)C`$```
M2)#C$!````0'\0T0XQ`0#``4P/3___S%```$L,`0``!(A.,0$```!`?Q#1#C
M$!`,`!3`]/___+4```3(P!```$AXXQ`0```$!_$-$.,0$`P`%,#T___\I0``
M!.#`$```2&SC$!````0'\0T0XQ`0#``4P/3___R5```$^,`0``!(8.,0$```
M!`?Q#1#C$!`,`!3`]/___(4```40P!```$A4XQ`0```$!_$-$.,0$`P`%,#T
M___\=0``!2CK;_`P`"3C\/](_W'C,/"H`"3C0/"@`"10(/"T04#PH$$P\*A!
M(/"TP.7___Y\Q$@``$AIQ"@``$ABN00`-,#E___](<08``!(+I4`$`"G=``>
MP.7___W7Q"L``$C`["8`"`!\IRD``<#E___^C,#E___^Z<08``!(*N,@$```
M%L#E____8)(`*CG$N```2!_C(+```!;`Y?___U66`B2*XR"P```6P.7___]-
ME@$DBE@@\+3LL@`#`-BG*@`$N10`(NLB``,`#<#E___^G.-`\*@`!.,00```
M!.,0(```),`0```:T^,0(`@`),08``!(1N,0(!``),`0```:R>,0(!@`)+D$
M`%+$*P``2&"G&``!XR#PM``2N?+0(:<Y``#L$P`$`-BG.P`!N10`$>L1``,`
M#;D(`!6G)@!7N10`2^5($````*=I``#`,```!$_$*```2$3`Y?___/48LNPF
M``H`?L0H``!(.L#E___^*QBRQ"@``$@SP.7___V4P"```!F`P.4```&:["8`
M'P!\P!```$@@XQ`0```"IW0`"\`@```91\#E```!B<0K``!($L`0``!(#^,@
M$````J>$``7`Y0``##/$*```2`C`Y?___NG`Y?__^Z:Y%``KZV_PZ``$!_[K
MHP`#``WC"D````3C`!```"2G]/^4!P<'![D$`"_`,````!+C,#```!BG^_]@
MIPD``.,`\```),#T````"0<'!P<``(KP!P<'!^MO\#``)$%`(`CC\/]8_W'$
M:```1S3E2/"@``#$6```1SKC,"`$`!3$*```1QS`Y?___3'K;_#8``0'_@<'
M!P?`$```1XC`(```1X7L$@`*@&3$&```1QOL&``$`'P'\0?^!P<'!P<'P!``
M`$=TP#```$=QN0D`,>L3``,`"NLS`#\`#+D(`#'K,P`!``KL.``-`'S$&```
M1Q+L&``'`'S`(```1U@'\0?^!P<'!P<'ZY_P2``DP)```$=-X_#_8/]QE0"0
M`*=T`$O`$```1N_C$!````*GA``(Q"@``$;_P.7___T8P!```$3YP+```$3Z
MP*```$3SN0D`L<08``!'+NN[``,`"J>[___L&P`5H&6G&P`!Q!L``$<AZQ$`
M`P`-XQ&@```$#>'$&```1Q?L&__Q0&7`Y?___X7`$```1J+C$!````*GA``(
MP"```#?*P.7___L_D@&0`.N?\.@`!`?^!P<'!^OO\'``)./P_V#_<>OO\1``
M!`?^!P<'!\`0``!&F.,0$````J>$`!?K[_!P`"3`,```1N7C\/]@_W'`(```
M-Y_`Y?___,3K[_$0``3`]/___UK`]/___U?K[_!P`"3C\/]@_W'K[_$0``0'
M_@<'!P?K;_`P`"3C\/]@_W'L*`!-`'S$&```1EOCH!````*GA`!$N00`8[D$
M`(*Y!`!"XQ!```"4[!8`+@!^&TBY!`!ZN10`E..P<````J>$`!VY!`!)N00`
M.+D$`"O`Y?__^U_L)@`?`'Y!&;``E3T0`*=T`!BYZ:"G0;FP`>NJ``,`"E"@
M8`"Y!``KZV_PT``$!_[L&/_5/7Y!0$`!I_3_RD%P<`BG]/_1I[D``*?T_^T'
M!^N_\%@`)./P_U#_<;)/`+!!,/"DZ[L`(``-LD\`L=('\*BP*,#E____EM4'
M\*BP**>$``7`Y?___6KKO_$(``0'_@<'!P<'!^N?\$@`)./P_U#_<;)/`*#K
MJ@`@``VR3P"AN00`LM('\*B@*$&0\*2Y!``YN00`*\#E____;.PF``L`?-4'
M\*B@**>$`![`Y?___3WC$/"D`!3$*```1;_K$0`#``WC$"````CC(!`(``3C
M(!```"3L*/_<`'Q!$!`(I_3_]>N?\/@`!`?^!P?K;_`P`"3C\/[(_W&R3P"0
MZYD`(``-LD\`D=('\3"0*.PH`"<`?+D$`**5`"``IX0`(,#E___YH[D$`'+L
M*``9`'Q!8/"@N00`)\#E___Z1[D$`++L)@`5`'RY!``GP.7___K-N00`*L#E
M___\.-4'\3"0**>$`&[`Y?___.!!L+`3P!```!;7IP@``+D$`"NR70`2IQ3_
M_J>$_]?`$```%M^Y!``KLET`$J<4__ZGA/_,N00`*J<9``"R7@`2IQ3__KD$
M`#NY"0`:IRD``+)>`".G%/_^N0D`*QH2IQH``KD4`"'`Y?__^CK`,```%KJY
M!`""N00`6[D$`$K`Y?___&ZY!``VN00`*,#E___\)^PH`!G_?E@0\+BG*$``
MP!L``/``[!(`#V!VN00`*,#E____:;D$`"C`Y?___`"G]/^$N00`*,#E___Y
M^:?T__3K;_%H``0'_NNO\%``)./P_LC_<;)/`+"Y!`"BZ[L`(``-03#PH+)/
M`+'2!_$PL"C`Y?__^BSL)@`I`'X8$J<X0`!8(/"XP"L``/``[",`"(!VI3^@
M`.PC``]@=J<Y``*Y!``JP.7___DB$!*G&O__B!``']4'\3"P*+D4`"&GA``)
MP.7___PSIQ@``*?T__3KK_&(``0'_NMO\#``)./P_U#_<;)/`(#KB``@``VR
M3P"!N00`HM('\*B`*+D$`+.5/3``IW0`!$&P,`&G"```N00`&Z>9``!!,/"D
MLEX`D:<4__ZY!``JN0D`F\#E___^(NPH`"8`?*<(``"G&0``N00`,K)>`!.G
M%/_^N0D`$NR1`%\@9:<9``#C,;```)!",2``IQL``>PV__D`?-4'\*B`**>$
M`,?`Y?__^]C$&```1%WCT!````2G&0``&'&G&P`!ZR$``P`-XR+?^/\"IW3_
M]^PG``(`V,`0``!$O[D4`"+C$!```!+K(@`#``VGA`!]N00`,KD$`"W`Y?__
M^&[$&```1#/C(!```"3L*/_(`'SL%P`!`-C$*```1">Y%``1XR`@```$ZQ$`
M`P`-01$@`.5($````%!P\*2Y!``:XR`0``"4["@`!@!^["8`;CU^N0D`&NPI
M``(`V;D8`"'$>```1`/C8/"D`!3K9@`#``WC8'````C`Y?__^/_C(&```"3L
M*/^,`'SC$/"D`!3C('````3K$0`#``WC$2````3C(*```)!"(!``0:"@`;D$
M`#'`*P```/]!$!`!IX0`!>PF__`]?I(],`"G*0``XS*P``"00C(0`*<K``'L
M-O_Y`'RG]/]<P!```$0WY4P0```!P.7___C!N00`8NPH_T\`?+D4`$>Y!``]
MZT0``P`-P.7___C"Q!@``$.GXV`0```DI_3_=T$0$`&G]/^*ZV_PX``$!_X'
M!P<'!P?K[_!P`"3$&```0XWC\/]@_W'C(!```!;`Y?__^L#`4```-"3$2```
M0Y+`,```%0WK[_$0``3`]/__^I$'!P<'ZV_P,``DX_#_6/]QQ+@``$-JXR"P
M```6P&```!9"P.7___J=P.7____.XR"P```6P.7___J4N00`5N5(\*```,!`
M```&O,`P```4[<#E___WQNMO\-@`!`?^!P<'!P<'ZV_P,``DX_#_4/UQXQ#P
MJ`)QLD\`@.N(`"``#;)/`('2!Q``@"C`Y?__]^E!L/"FN00`4L!@```4T<!`
M```4T*<Y$`&Y!``KP.7___>(["8`$/]^I[D``.,0\*@"<=4'$`"`**>$`$K`
MY?__^HCL(!``(''L)/_P`'[CH/"G`7&G21``N00`.KD$`"O`Y?__^0:Y!`"2
M["3_WP!^IRH``;D4`"+`Y?__]_JY!`"R["C_TP!\N10`>>PJ``>@9;GH<!*Y
M84"A[+H`!\!EN>AP&KEA0+'LD!`!('*Y!`!'N00`.KD$`"O`Y?__^BE!%[``
MD@`0`*?T_[*Y!``KZV_PX`($!_X'!P<'P/3___]\!P?K;_`P`"3C\/[`_G'C
M$/$X`7&Y!`"RN00`<[)/`(#`(```%%SKB``@``VR3P"!T@<0`(`HP.7___R6
MISD`+[D$`)*Y!``KP.7___A1["@`%@!\N00`.\`@```41<#E___]WN,0\3@!
M<=4'$`"`**>$`*[`Y?__^?NG"```N00`&[D$`">GJ0``P#```!0SLEX`H:<4
M__[`Y?__^9D;J[D$`%*GJ@`!07#Q.$'0\*CL6/_2`'R5`%``P!```!/4N>*`
M4>R8`!L`?*<(``"Y!``5N00`*;)=`!*G%/_^IW0`#L`P```4!Z<I``#`Y?__
M^6^Y!`!2I_3_W:<(``"G&0``N00`);)>`!*G%/_^&Q7L,?__`-BY!``EN1@`
M(Y4O(`"GA``A&AJG*`__[!+_E"!VX[#PH``DP&```!/=P$```!1'ISD0`+D$
M`"?`Y?__]G^G&!``IRH``>PA``K`=Z?T``&2`"``&!.G]/_3N00`/;D$`"?`
MY?__^0KL)O^S`'Y8$/#`I2^``,`;``#P`.P2_ZE@=J<Y``&Y!``GP.7___9&
M[";_GP!^N00`-\`@```3FL#E___],[D$`"?`Y?__]T:Y!`"RI_3_3KD$`"OK
M;_%P`00'_@<'N00`$N,P$```E.PV``0`?@?^01`0`:<^`"^YXH`AI_3_\P<'
M!P<'!^PH``D`?+D$`#*5`"``IW0`",`@```3)\#T___W&*<(``"G&0``LEX`
M$J<4__[C0!___W&YZ3`A[#0`!B!E[#8`!?]\IRD``:<G`!/L-``J8&25+S``
MIX3_WL`@```32Z?T_]SC0$___W&G]/_OE2]``*>$__FYZ3`4IQL``;DA`#2G
M*0`!N>(P$J<7``2G]/_?XR!/__]QE2]``*=T`#:YZ3`4XR!/__]Q[#(`!B!E
M[#8`!?]\IQD``>-`3___<:<7`"BY"0!#IRD0`.P4``(`V>P2`"4@9>OO\'``
M)*=+``'C\/]@_W'L0!``(''`(```0<W`Y?__]UK`(```0<?K[_$0``0'_KD$
M`$*G]/^_E2]``*>$_].G]/_6IRD```?^!P<'!P<'Z[_P6``DP!```#'$X_#_
M,/]QLD\`L.N[`"``#;)/`+'2!_#(L"C2(?"F$`K`(```$L_`Y?__^R?`(```
M$L[`Y?__^R'`(```$LS`Y?__^QO`(```$LO`Y?__^Q7`(```$LG`Y?__^P_`
M(```$LO`Y?__^PG`(```$IW`Y?__^P/`(```$L7`Y?__^OW`(```$L3`Y?__
M^O?`(```$L/`Y?__^O'`(```$HK`Y?__^NO`(```$KS`Y?__^L'L*``+`'RY
M!``RP"```!*GP.7___P2P"```!*TP.7___JPN00`,NPH``D`?,`@```2*<#E
M___\`<`@```2K,#E___ZG[D$`#+L*``:`'S`(```$E+`Y?__^_#`,```$K+`
M(```$FG`Y?__^^?5!_#(L"BGA``FP.7___@'P"```!*2P.7___I]N00`,NPH
M``@`?,`@```27J?T_]ZG20`*P#```!*)02#PM\#E___UG>PF_]4`?D$P\,&G
M]/_LZ[_Q*``$!_X'!P<'!P?$'0``0(2G'O__IW0`+NOO\'``),`@```2-^/P
M_V#_<<#E___Z2.PH`!P`?.,0(```D)4`(`"GA``4P!<````PN0,`$>P1/[\!
M5<0?``!`7^OO\1``!,0L``!`60?^IQ@``*?T__3$+```0%$'_@<'Z^_P<``D
MX_#_8/]QP.7___>NP.7___7[["@`!@!\XR`@```$Z^_Q$``$!_X'!P<'ZV_P
M,``DN00`LN/P_V#_<<`@```2(L#E___Y_;D$`#OL*``)`'RY!`!BE0`@`*=T
M``O`(```$A'K;_#0``3`]/__^T7`Y?__]7KL)@`M`'RG"```N00`&[)>`"&G
M%/_^N00`-J<9``"R7@`3IQ3__KD)`!:Y"0`K02(0`L#E___TWL`P```1_+D$
M`*+`4```$8FY!`!+P.7___<1N00`.J?T_\GK;_#0``0'_@<'!P?K;_`P`"3C
M\/X8]W'C$/'@"'&R3P!PZW<`(``-LD\`<=('$`!P*,`0```_R;D$`(+`(```
M$5/2#_"P$`C2!_#`$!C2+_#@$"#2#_#($%#2!_#8$&#`Y?__^8;L*``?`'RY
M!`"RE0`@`*>$`!C`Y?___W+C$/'@"''5!Q``<"BGA``%P.7___;SN00`*^MO
M\A@(!,#T___TV\#E____1+D$`++L)@`E`'Q!H/#(XR"@```"IW0`!\"P```1
M?Z?T`!C`Y?__^5#L)@`'`'RGJP`(I_3_[I4`(`"GA/_ZP.7___2VN00`LNPH
M__,`?*<(``"Y!``;IRD``+)>`"&G%/_^N0D`*^LB``$`#:<K``'`Y?__]#VY
M!`!BN00`HN-`L```E.Q&`)L`?D&@\.#CL*````*GA``=N00`*\#E___Y$[D$
M`++L*`":`'R5`"``IX0`E<#E___Z&^PH`)``?KD$`"O`Y?__]'.Y!`"R0:#P
ML.RV``P`?..0H````J>$``:5`)``IW0`?J<(``"Y!``;IYD``+)>`)&G%/_^
MN00`)J<9``"R7@`2IQ3__KD)`!:Y"0";&I&GF@0$N10`F;D$`"G`Y?__\^/C
M8/"@`"2Y!`"BP#```!#[P&```!#UP%```!")N00`2\#E___V$*<Y`<"Y!``J
MP.7___6I["8`5?]^P.7___636&`@`.QH`$T1?L08```^E[D4`&:Y!`!:XT"`
M```$P#```!#6XR`0```$P.7___4+I[D``.,0\>`(<=4'$`!P**=T_QVY!``K
MZV_R&`@$!_ZY!``JN10`1,`P```0KL#E___UT4&PL`%!H*`"I_3_5*>K``BG
M]/]8N00`*<#E___Y@NPH``H`?KD$`"G`Y?__\]JY!`"RIZL`"*?T_V=!,/$0
MN00`*L#E___SK1C2["@`%@!^Q!@``#Y"N00`6N-`@```!,`P```0H>,@$```
M!,#E___TN*?T_ZU8$/$HIRA``,`;``#P`.P2_^9@=EBP\2S`Y?__]<?LLO_>
M8'98$/$HIR@!P,`;```!_^P2_]1@=KD$`"G`Y?__\S6Y!`"RP"```!"=P.7_
M__@9["8`Q@!\XY"````$IP@``*<9``"Y!``ILEX`$J<4__ZY"0`9[!P`/@-^
MN10`(>,RG_S_<<`@```0@+)=`".G%/_^IW0`+^P8``T$?J<:__NY%``101&0
M`)4O$`"G=``BXQ"`"``"IX0`':<(``"G*0``N00`,;)>`".G%/_^N0D`(>PL
M``\#?>,R'_S_<<`@```05K)=`".G%/_^N>*`D<#E___];NPF`-\`?KD$`"FG
M.0``P.7___-`N00`DAB"["@`T@!^ITD``J<Y_^Y!8/'@P.7___)AITD`!KD$
M`#:Y!``IP.7___18E0#QX*=T`&.50_'AIW0`7Y5!\>*G=`!;E4/QXZ=T`%>5
M2/'DIW0`4Y5%\>6G=`!/ITD``J<Y_\:Y!``IP.7___(WITD`*;D$`#:Y!``I
MP.7___0NP!```!!=XQ#PH``DP%````\YN00`2L`P```/]KD$`"O`Y?__]+NY
M!``JP.7___1FN00`.\`@```/&,#E___XMKD$`"O`Y?___4VG]/[`XY"````$
MP.7___+!N00`,KD$`"G`Y?__^I:Y!`"2[";_,0!\I_3_*Z=)``"G.0``N00`
M*<#E___QZL#E```-![D4`(BY!`#2I4^``+D$`#:Y!``HP.7___/:["(`-`!^
MN00`*$&0\:-!@/&WP.7___.NN00`/;D$`"FY!`#8P.4```W%IVD`%.-`D```
MD+D$`"C`,```#S7`Y?__]%BGFP`!IXL``J=G__'`$```#^&2`/'?XQ#PH``D
MN00`;:?T_X"Y%`!"N00`-KD$`"W`Y0``#/6G]/^ZP#````\%P"````[*P.7_
M__@ZP.7___&?P!````^^N00`8N,0\*``),!0```.F+D$`$K`,```#UVY!``K
MP.7___0:ISD!P+D$`"O`Y?__\[/L)O]8_W[`Y?__\YU8$"``IQX`$:=T_T[`
MY?__\73`$```#Y/C$/"H`"2GV@`!N10`';D$`&+C$/"@`"3`4```#F:Y!`!*
MP#````\RN00`*\#E___SZ*?T_\X'!P<'!P?KG_!(`"3C\/]@_W'$J```/([C
M(*```!;`Y?__\\2Y!`"RXR"@```6P.7___.\T@`@N;"XP"````Y-P.7___9O
M["@`"P!\E3$@`*=T``:5`"`!IX0`!<#E___[1<2H```\9N,@H```%L#E___S
MG*=9``.G20`!P#````[SP.7___("N00`LNPH`"X`?.,@H```%L#E___SA^,0
ML!``!,!````.X.,P$```!,#E___R"^,0L!``!.,0$```!)%`$`VGA``1XR"@
M```6P.7___-KXQ"P$``$XS`0```$P.7___$2Q)@``#PCXR"0```6P.7___-9
MIUD``Z=)``'`,```#K3`Y?__\;^Y!`"R["@`/P!\P"````W#P.7___8`N00`
MHNPH`!8`?.,@D```%L#E___S.>,0L!``!+D$`$KC,!````3`Y?__\;ZG]``@
MP.7___BMN00`HN,@D```%NRH`%\`?,#E___S'N,0L!``!+D$`$KC,!````3`
MY?__\:.Y!``JP.7___+.Q+@``#O/XR"P```6P.7___,%N00`HN,@L```%L#E
M___R_:=)``'`,```#EO`Y?__\`7`0```#F"Y!``RN00`*L#E___Q>^,@L```
M%L#E___RY9(`(+G`(```#5?`Y?__]9G$*P``/"+L)@`C`'S$*```/!C`Y?__
M^]W$*P``/!;L)@`7`'S`(```#CG`Y?__\!7`Y?__\L+$.```/`/C$+`0``3C
M0#````2G]/^%ISD!P,0H```[^L#E___R7[D$`%+L*``8$7[L$@`!`-CL'``2
M`7_$&```.^7$2```.^;C,!````3`(```#AK`Y?__[^7KG_#H``0'_@<'!P?K
MK_!0`"3C\/]@_W&Y!`"RP.7___F0P.7___EYN00`HL#E___ZX.PH`!T`?NRX
M`!H`?)4`L`"GA``5P#````U<N00`*L#E___PNNRB``M@9+D$`"OKK_#P``3`
M]/__]8/KK_#P``0'_K)/`!#K$0`@``VR3P`1ZV_P,``DIUD`"./P_-#_<=('
M\R@0**>Y``!!$/"HN00`,>-+(#@`!.L$`"``#.,`,```),!*`````.-`,`@`
M)*>[``BG.P`0IU?_[:=)`$#C,!!H``3C,!!``(+C,!`0`(+C,!```(+L4R"_
M(57L4R`^`5;C4!"``"2G&P`(IT?_Z>.@\*@`!,*J6H)YF>.@("``".,P(```
M!.-`(!``!.,`(`@`!.,0(!@`!.,0\*``).RS(+\E5;GG$!3LLR`Z!5:Y@``0
MN0@`NN,0\*``@NN0``(`#+D(`+'LD``A'E;LV2"_`%6YY]"DN8``H[F"`*3L
M>R"_`%7C@/"P``3"BEJ">9GC@/"@``BY"`"*[*L[OR55Z[,``@`,[*<`.@56
M[+,`(1Y6N0@`J+F"`)NY@`"7N>?0&>R*(+\`5>QK(+\`5>.0\+@`!.-0\,``
M!,*:6H)YF<):6H)YF;D(`)2Y"`"1[!H[OR55ZZ<``@`,[*<`(1Y6N8(`NKF`
M`+BY@@"V['H@OP!5[!@`.@56N0@`U;D(`!FY"`#;[)$@OP!5Z[@``@`,XU#P
MR``$[+@`(1Y6PEI:@GF9N8(`J[D(`&6Y@`"IN8(`I[D(`*;LBR"_`%7L$3N_
M)57C4/#0``3L&0`Z!5;"6EJ">9FY"``=[-$@OP!5[!$[OR55[!T`.@56N0@`
M&NNI``(`#.RI`"$>5KF"`+JY@`"]N8(`N.QA(+\`5>R:(+\`5;D(`'7C4/#8
M``2Y"`![PEI:@GF9Z[T``@`,[+T`(1Y6N8(`J[F``*:Y@@"I[-L@OP!5N0@`
MA>P1.[\E5;D(`(KL%@`Z!5;KI@`"``RY"``7[*8`(1Y6['$@OP!5N8(`NN-0
M\.``!+F``+?"6EJ">9FY@@"][&H@OP!5N0@`E>P1.[\E5;D(`)OL%P`Z!5;K
MMP`"``RY"``8[+<`(1Y6[($@OP!5N8(`J^-0\.@`!+F``*C"6EJ">9FY@@"F
M['L@OP!5N0@`U>P1.[\E5;D(`-KL&``Z!5;KJ``"``RY"``9[*@`(1Y6[)$@
MOP!5N8(`NN-0\/``!+F``+G"6EJ">9FY@@"W[(H@OP!5N0@`9>P1.[\E5;D(
M`&OL&0`Z!5;KN0`"``RY"``=[+D`(1Y6[-$@OP!5N8(`J^-0\/@`!+F``*W"
M6EJ">9FY@@"H[)L@OP!5N0@`=>P1.[\E5;D(`'KL'0`Z!5;KK0`"``RY"``6
M[*T`(1Y6[&$@OP!5N8(`NN-0\0``!+F``+;"6EJ">9FY@@"Y[-H@OP!5N0@`
MA>P1.[\E5;D(`(OL%@`Z!5;KM@`"``RY"``7[+8`(1Y6['$@OP!5N8(`J^-0
M\0@`!+F``*?"6EJ">9FY@@"M[&L@OP!5N0@`E>P1.[\E5;D(`)KL%P`Z!5;K
MIP`"``RY"``8[*<`(1Y6[($@OP!5N8(`NN-0\1``!+F``+C"6EJ">9FY@@"V
M['H@OP!5N0@`U>P1.[\E5;D(`-OL&``Z!5;KN``"``RY"``9[+@`(1Y6[)$@
MOP!5N8(`J^-0\1@`!+F``*G"6EJ">9FY@@"G[(L@OP!5N0@`9>P1.[\E5;D(
M`&KL&0`Z!5;KJ0`"``RY"``=[*D`(1Y6[-$@OP!5N8(`NN-0\2``!+F``+W"
M6EJ">9FY@@"X[)H@OP!5N0@`=>P1.[\E5;D(`'OL'0`Z!5;KO0`"``RY"``6
M[+T`(1Y6[&$@OP!5N8(`J^-0\2@`!+F``*;"6EJ">9FY@@"I[-L@OP!5N0@`
MA>P1.[\E5;D(`(KL%@`Z!5;KI@`"``RY"``7[*8`(1Y6['$@OP!5N8(`NN-0
M\3``!+F``+?"6EJ">9FY@@"][&H@OP!5N0@`E>P1.[\E5;D(`)OL%P`Z!5;K
MMP`"``RY"``8[+<`(1Y6[($@OP!5N8(`J^P1.[\E5;F``*CL&``Z!5:Y@@"F
MN0@`&>-0\3@`!,):6H)YF;D(`-6Y"`"M[)$@OP!5['L@OP!5[-$[OR55[-$@
M.@56XQ#Q0``$N0@`VL(:6H)YF>NH``(`#+D(`&'LJ``A'E:Y@@"ZN8``N;F"
M`+>Y"`"VXQ#Q2``$[&T[OR55PAINV>NA[&T@.@56N0@`%[D(`&OKN0`"``SL
MN0`A'E:YY[":N8(`G;D:`!GL=CN_)57LG2*_/E7L=B`Z!5;LG0(A'E:Y"`!Q
MN>>0B^,0\5``!+F"`(;"&F[9ZZ&Y&@`:N1H`&.R&(K\^5;D$`*'LA@(A'E;L
M%SN_)57L%R`Z!5:Y"``:XZ#Q6``$PJINV>NAN>>`:;D:`*NY@@!GN00`NKD:
M`+;LH3N_)57L9R*_/E7LH2`Z!5;L9P(A'E:Y"`"KN>=@>..P\6``!+F"`''"
MNF[9ZZ&Y&@"YN1H`M[D$`)OLNCN_)57LNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6
MXQ#Q:``$N>>0=L(:;MGKH;F"`'JY&@`8N1H`%[D$`('L&SN_)57L&R`Z!5:Y
M"``8[(HBOSY5[(H"(1Y6XZ#Q<``$PJINV>NAN1H`IKGG@&FY@@!KN1H`IKD$
M`'KLH3N_)57LH2`Z!5:Y"`"G['LBOSY5['L"(1Y6X[#Q>``$N>=P:,*Z;MGK
MH;F"`&&Y&@"YN1H`MKD$`)OLNCN_)57LNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6
MXQ#Q@``$N>>09\(:;MGKH;F"`&JY&@`8N1H`%KD$`('L&SN_)57L&R`Z!5:Y
M"``8[(HBOSY5[(H"(1Y6XZ#QB``$N>>`:<*J;MGKH;F"`&NY&@"GN1H`IKD$
M`'KLH3N_)57LH2`Z!5:Y"`"G['LBOSY5['L"(1Y6X[#QD``$N>=P:,*Z;MGK
MH;F"`&&Y&@"YN1H`MKD$`)OLNCN_)57LNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6
MXQ#QF``$N>>09\(:;MGKH;F"`&JY&@`8N1H`%KD$`('L&SN_)57L&R`Z!5:Y
M"``8[(HBOSY5[(H"(1Y6XZ#QH``$N>>`:<*J;MGKH;F"`&NY&@"GN1H`IKD$
M`'KLH3N_)57LH2`Z!5:Y"`"G['LBOSY5['L"(1Y6X[#QJ``$N>=P:,*Z;MGK
MH;F"`&&Y&@"YN1H`MKD$`)OLNCN_)57LNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6
MXQ#QL``$N>>09\(:;MGKH;F"`&JY&@`8N1H`%KD$`('L&SN_)57L&R`Z!5:Y
M"``8[(HBOSY5[(H"(1Y6XZ#QN``$N>>`:<*J;MGKH;F"`&NY&@"GN1H`IKD$
M`'KLH3N_)57LH2`Z!5:Y"`"G['LBOSY5['L"(1Y6X[#QP``$N>=P:,*Z;MGK
MH;F"`&&Y&@"YN1H`MKD$`)OLNCN_)57LNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6
MXQ#QR``$N>>09\(:;MGKH;F"`&JY&@`8N1H`%KD$`('L:B*_/E7L&SN_)57L
M:@(A'E;L&R`Z!5;CH/'0``2Y"``8PJINV>NAN1H`I[GG8'FY@@![N1H`I[D$
M`(KCT/'8``3LH3N_)57"VF[9ZZ'LH2`Z!5:Y&@#9N0@`J.R+(K\^5>R+`B$>
M5KD$`+VYYX"6N8(`D;D:`+GL>B"_`%7LVCN_)57LUP`Z!5:Y"`#;[+$BOSY5
M[+$"(1Y6XQ#QX``$PAINV>NAN1H`%K/!``&YY[`8N8(`&K/-`*#LG2"_`%7L
MW3N_)57LV0`Z!5:Y&@"AZQ<``@`,N0@`K>P7`"$>5NQQ(+\`5;GF$-NYY'!;
MN8``V;F!`-7L:B"_`%7C4/'H``3"6H\;O-RY&@!8N>A0C>S:.[\E5>NI``(`
M#.RI`"$>5KF!`!JY@``6N>1PFKF!`)'C$/'P``3"&H\;O-RY&@`;N0@`&>S6
M`#H%5KD(`-CLC2"_`%7LO3N_)57LN``Z!5:Y"`"QZQ8``@`,[!8`(1Y6[&$@
MOP!5N>1@6KGF$-JY@`#8N8$`U>-0\?@`!,):CQN\W+D(`'7LFR"_`%6Y"`#7
M['L[OR55Z[@``@`,[+@`(1Y6N8$`&[F``!FYY&"+N8$`@>,0\@``!,(:CQN\
MW+D:`!JY"``8['D`.@56N0@`?>S7(+\`5>RG.[\E5>RM`#H%5KD(`*'K&0`"
M``SL&0`A'E;LD2"_`%6YY)!;N>80>[F``'VY@0!UXU#R"``$PEJ/&[S<N0@`
M9>R*(+\`5;D(`';L:CN_)57KK0`"``SL:``Z!5;LK0`A'E:Y"`!GN8$`&KF`
M`!CL=B"_`%6YY)#:N8$`T>,0\A``!,(:CQN\W+D:`!OLMCN_)56Y"``=[+<`
M.@56N0@`L>QK(+\`5>L8``(`#.P8`"$>5NR!(+\`5;GD@%JYYA#:N8``U[F!
M`-7C4/(8``3"6H\;O-RY"`"5N0@`V>R;.[\E5>NW``(`#.RW`"$>5KF!`!NY
M@``6N>2`>[F!`''C$/(@``3"&H\;O-RY&@`:N0@`%^R6`#H%5KD(`)WLV2"_
M`%7LJ3N_)57LK0`Z!5:Y"`"AZQ8``@`,[!8`(1Y6['$@OP!5N>1P6[GF$&NY
M@`!MN8$`9>-0\B@`!,):CQN\W+D(`(7LFB"_`%6Y"`!H[(H[OR55ZZT``@`,
M[*T`(1Y6N8$`&KF``!FYY'#:N8$`T>,0\C``!,(:CQN\W+D:`!NY"``=[(D`
M.@56N0@`ANQH(+\`5>RX.[\E5>RV`#H%5KD(`+'K&0`"``SL&0`A'E;LD2"_
M`%6YY)!:N>80VKF``-:Y@0#5XU#R.``$PEJ/&[S<N0@`=>R+(+\`5;D(`-?L
M>SN_)57KM@`"``SLM@`A'E:Y@0`;N8``&+GDD&NY@0!AXQ#R0``$PAJ/&[S<
MN1H`&KD(`!;L>``Z!5:Y"`!][-<@OP!5[*<[OR55[*T`.@56N0@`H>L8``(`
M#.P8`"$>5NR!(+\`5;GD@%NYYA!KN8``;;F!`&7C4/)(``3"6H\;O-RY"`"5
M['H@OP!5N0@`:>R:.[\E5>NM``(`#.RM`"$>5KF!`!JY@``7N>2`VKF!`-'C
M$/)0``3"&H\;O-RY&@`;N0@`'>R7`#H%5KD(`);L:2"_`%7LN3N_)57LM@`Z
M!5:Y"`"QZQ<``@`,[!<`(1Y6['$@OP!5N>80VKGD<%JY@`#6N8$`U>-0\E@`
M!,):CQN\W+D(`(6Y"`"-Z]8``@`,[-8`(1Y6N>;08;GD<!WLFR"_`%7LNSN_
M)56Y@`!I[+D`.@56N8$`8;D(`+CC$/)@``3"&H\;O-RY&@`:N0@`8>R+(+\`
M5>P;.[\E5>NY``(`#.P8`#H%5NRY`"$>5KD(`!;LFR"_`%6YYK!MN>207;F`
M`&BY@0!EXU#R:``$PEJ/&[S<N0@`=;D(`';K:``"``SL:``A'E:YYF"+N>20
MMNRA(+\`5>P1.[\E5;F``(KL&@`Z!5:Y@0"+N0@`%^.P\G``!,*ZCQN\W+D:
M`+WL<2"_`%6Y"`"+[+$[OR55ZQH``@`,[!H`(1Y6[*$@OP!5N>2@5KGF$-;L
MMP`Z!5:Y@`#7N0@`N+F!`-7C4/)X``3"6H\;O-RY"`"5N0@`V>R+(+\`5>R;
M.[\E5>R;(#H%5KD(`)WKUP`"``SLUP`A'E:YY*"]N8$`';F``!BY@0`;X[#R
M@``$PKJ/&[S<N1H`MKD(`+'K>``"``SL&3N_)57L>``A'E;L&2`Z!5:YYW"-
MN0@`&[F"`(GCL/*(``3"NLIBP=:Y"`"ZN1H`N.RA.[\E5>R)(K\^5>RA(#H%
M5NR)`B$>5KD(`*NYYX!GX[#RD``$N8(`8<*ZRF+!UKD:`+VY&@"VN00`F^QA
M(K\^5>RZ.[\E5>QA`B$>5NRZ(#H%5KD(`+GCD/*8``3"FLIBP=:Y&@"7N>=@
M>+D$`!FY@@!ZN1H`%^R;.[\E5>QZ(K\^5>R;(#H%5NQZ`B$>5KD(`)'C$/*@
M``3"&LIBP=:Y&@`8N>=PAKF"`(NY&@`8N00`H>R+(K\^5>P9.[\E5>R+`B$>
M5NP9(#H%5N.P\J@`!+D(`!K"NLIBP=:Y&@"VN>>`9[F"`&FY&@"VN00`J^QI
M(K\^5>RQ.[\E5>QI`B$>5NRQ(#H%5KD(`+KCH/*P``3"JLIBP=:Y&@"GN>=@
M>+F"`'&Y&@"GN00`FNRK.[\E5>RK(#H%5KD(`*GLD2*_/E7LD0(A'E;C$/*X
M``2YYY!VPAK*8L'6N8(`>[D:`!BY&@`7N00`@>P:.[\E5>P:(#H%5KD(`!CL
MBR*_/E7LBP(A'E;CL/+```3"NLIBP=:Y&@"VN>>`:;F"`&JY&@"VN00`>^RQ
M.[\E5>RQ(#H%5KD(`+?L>B*_/E7L>@(A'E;CH/+(``3"JLIBP=:Y&@"IN>=P
M:+F"`&&Y&@"FN00`FNRK.[\E5>RK(#H%5KD(`*GLD2*_/E7LD0(A'E;C$/+0
M``2YYY!GPAK*8L'6N8(`:[D:`!BY&@`6N00`@>P:.[\E5>P:(#H%5KD(`!CL
MBR*_/E7LBP(A'E;CL/+8``2YYX!IPKK*8L'6N8(`:KD:`+>Y&@"VN00`>^RQ
M.[\E5>RQ(#H%5KD(`+?L>B*_/E7L>@(A'E;CH/+@``2YYW!HPJK*8L'6N8(`
M8;D:`*FY&@"FN00`FNRK.[\E5>RK(#H%5KD(`*GLD2*_/E7LD0(A'E;C$/+H
M``2YYY!GPAK*8L'6N8(`:[D:`!BY&@`6N00`@>P:.[\E5>P:(#H%5KD(`!CL
MBR*_/E7LBP(A'E;CL/+P``2YYX!IPKK*8L'6N8(`:KD:`+>Y&@"VN00`>^RQ
M.[\E5>RQ(#H%5KD(`+?L>B*_/E7L>@(A'E;CH/+X``2YYW!HPJK*8L'6N8(`
M8;D:`*FY&@"FN00`FNRK.[\E5>RK(#H%5KD(`*GLD2*_/E7LD0(A'E;C$/,`
M``2YYY!GPAK*8L'6N8(`:[D:`!BY&@`6N00`@>P:.[\E5>P:(#H%5KD(`!CL
MBR*_/E7LBP(A'E;CL/,(``2YYX!IPKK*8L'6N8(`:KD:`+>Y&@"VN00`>^RQ
M.[\E5>RQ(#H%5KD(`+?L>B*_/E7L>@(A'E;CH/,0``3"JLIBP=:Y&@"IN>=P
MF+F"`)&Y&@"I[)L[OR55[)L@.@56N0@`FNRA(K\^5>RA`B$>5N,0\Q@`!+GG
MH-?"&LIBP=:Y@@#;N1H`&+D:`!VY!`"![&D@OP!5[!D[OR55[!8`.@56N0@`
M&.R+(K\^5>R+`B$>5N.P\R``!,*ZRF+!UNS1(+\`5;D(`#OL$3N_)56YYX"Z
M[!T`.@56N1H`-[F"`)NY&@`YN0@`$\`:`````.,0(```)..@("``"+D(`-#C
M@/"@``C`V@````#CT"`(`"3`B@````#C@"`8`"3`J@````#CH"`@`"3K%@`"
M``SL%@`A'E:Y"`!!P$H`````XT`@$``DLD\`$.L1`"``#;)/`!'5!_,H$"BG
MA``%P.7__^>WZV_S8``$!_[K[_!P`"2G*0"`X_#_8/]QP.7__^4XP#%G12,!
MXS`@```DP#_OS:N)XS`@"``DP#^8NMS^XS`@$``DP#$0,E1VY4@@*```XS`@
M&``DY4@@,```P#_#TN'PY4P@>```XS`@(``DZ^_Q$``$!_X'!P<'ZV_P,``D
MZQ0``P`-N00`HKD$`+3C("`H``2Y"``2[$$@OP!5X_#_8/]QN3$`(:?$``7K
M`:`P`'KC0*`H`"3K&P`=``SC$*`P``CC$*`P`"1!D*`XXQ"@>``2IX0`,:>(
M`$`;@1F+N00`*;GRL(NY&``AN10`2.PC``>@9;GH0!*Y84`QN>A`<^PC``7`
M9;EA0"?`Y?__YP\8&%H0H'A0$*!X[!8`,D!^N00`*ANXN10`N\#E___TA[D$
M`#?KBP`&`-ZGB@`!$KNG&``!N?)0@4%@H'BGA@`?[#D`!\!EN>BP&;EA0#'L
M.0`'H&6YZ+`3N6%`D;D$`$NY!``IP.7__^;:4+"@>.MO\-``!`?^I_0``>PY
M``;`9>PV__M`94%P,$#LDP`&P&7LE__S0&72/Y``,`"Y!``JI[K_P+D4`+O`
MY?__]$"Y!``WI_3_Q0<'ZX_P0``DN00`HN.0,"@`!..`,#``!.PI.K\]5>P2
M``$`V+D4`")!(C`XDH`@`./P_V#_<;D4`"&Y!`"S04(P..P<`%DX?J<H`$"G
M60``N?D0$KD$`"2Y%@`QITD``*@D``"G%/_^N00`*\#E___T`]<WL#BP.$*`
ML'-"D+!WZQ@`&``,0A"P<.L8`!``#$(0L''K&``(``Q"$+!RZQD`&``,0A"P
M=.L9`!``#$(0L'7K&0`(``Q"$+!VN00`*\#E___SV=(#H`"P!+D$`"O2`Z`$
ML`S2`Z`(L!32`Z`,L!S2`Z`0L"3KC_#@``3`]/__Y=JG*``XIUD``+GY$!*Y
M!``DN18`,:=)``"H)```IQ3__J?T_[('!\08```LX.P8`!K_?.N_\%@`)./P
M_V#_<<"P```LU`WAX["_^/]QXQ"P```$[!;_^?]\Z[_P^``$!_X'_@<'!P?K
M[_!P`"3C\/]@_W'K[_$0``0'_@<'!P?K[_!P`"2Y!``/I_O_8.,`\```),#E
M___GGNOO\1``!`?^+W1M<```+@!005)?5$U01$E2``!414U01$E2`%1-4`!5
M4T52``!54T523D%-10``+BX``"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN
M84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5```97AE`"]P<F]C+R5I+R5S
M`%!!4E]414U0``!005)?4%)/1TY!344``#H`+P!015),-4Q)0@``4$523$Q)
M0@!015),-4]05```4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$
M14)51P``4$%27T=,3T)!3%]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'
M3$]"04Q?0TQ%04X``%!!4E]#3$5!3CT``#$`3$1?3$E"4D%265]0051(`%-9
M4U1%30``)3`R>```<&%R+0``)7,E<R5S)7,``"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S
M.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R
M96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@``'!A
M<FP``"YP87(``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S`"5S)7-T
M96UP+25U+25U)7,``!@`<&5R;```,`!005(Z.E!A8VME<CHZ5D524TE/3@``
M,2XP-3(`56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``"UE```M+0``979A;"`G97AE8R`O=7-R+V)I;B]P
M97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)
M0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C
M:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@
M/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H
M:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@
M6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S
M92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I
M;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S
M*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE
M86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI0
M05(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*
M)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E
M;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I
M9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?
M<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?
M1D@L("<\.G)A=R<L("1P<F]G;F%M92!O<B!L87-T.PIM>2`D8G5F.PIM>2`D
M<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P
M,C0["FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@
M>PHD;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D
M8VAU;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI]
M(&5L<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW
M:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?<&]S
M+"`P.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!
M4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)
M0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?
M<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\(#`[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L
M(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B
M=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES
M=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;
M56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@
M)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E
M9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_
M*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@
M)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B
M87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE
M;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]
M"B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C
M(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D
M8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D
M=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4[
M"FUY("1I;F9O(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@;W(@
M<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L
M92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE
M.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D
M:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E
M*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I
M.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A
M<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D
M9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P
M<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@
M0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ
M1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I
M<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I
M;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N
M86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\[
M"GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@
M=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*
M;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C
M:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET
M:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@
M/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O
M<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM
M>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL
M7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF
M>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I
M('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`
M05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D
M9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)
M34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2![
M"G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*
M979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@
M0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D
M,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*
M96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@
M*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I
M('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N
M(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C
M86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]
M("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN
M:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C
M;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I
M(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I
M;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P
M87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I
M('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T
M(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&
M:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B
M)'!A<B)=.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T
M82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O
M+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@
M+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I
M('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T
M(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H
M+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U
M;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#<F5A
M=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*
M24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@
M24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@
M8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K
M(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)&1A=&%?<&]S
M*2!["G)E860@7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@96QS92!["FQO
M8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E]
M(&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H
M;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)&9H/CL*8VQO
M<V4@)&9H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I.PIO=71S*'%Q6U=R:71T96X@
M87,@(B1N86UE(ETI.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H
M*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@
M,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*
M;W!E;B!M>2`D9F@L("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4@)&9H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*
M?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N
M86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C
M:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE
M;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M
M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A
M<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C
M('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M
M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_
M.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF
M:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N
M86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2![
M"F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H
M<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92)=
M*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*
M?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@
M1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*
M<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C
M;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z
M.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I
M8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![
M(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E
M(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q
M=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T
M:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U0
M1$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D
M*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,
M;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M
M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@
M<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L
M("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@
M)"%=.PIS965K("1F:"P@+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U
M9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L
M(#(["G)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92![
M"FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@
M)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR
M87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M
M92(Z("0A73L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X
M+3YH97AD:6=E<W0["GT@?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E
M('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7([
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q
M(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M
M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*
M=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL
M;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64@;W(@
M9&EE('%Q6T-A;B=T('=R:71E("(D=&5M<&YA;64B.B`D(5T["G!R:6YT("1F
M:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M
M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA
M;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64[
M"GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]0
M4D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*
M)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[
M4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]
M*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%
M3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D
M0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*
M<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG
M>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D
M14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I
M<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P
M<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B
M+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I
M9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII
M9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*
M?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W
M*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I
M('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@
M5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@
M("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@
M)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,
M3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL
M(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@
M:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S
M('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G
M9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI
M=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN
M960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P
M<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X
M<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2
M.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H
M0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C
M<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN
M70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X
M:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X
M:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`
M`'!E<FQX<VDN8P!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```
M```!&P,[````T````!G__XW$```$T/__D<P```#L__^2?````2C__Y+$```!
M5/__DTP```&$__^4I````<#__Y4T```!\/__EVP```(L__^7K````DS__Y@,
M```"B/__F10```+$__^9'````MC__YKT```#%/__FQP```,H__^<1````TS_
M_YW,```#>/__GCP```.D__^>;````\3__Y\<```$$/__I60```1@__^G[```
M!)3__ZA4```%%/__OB0```50__^^E```!73__[_D```%L````!0``````7I2
M``%X#@$;#`^@`0```````#@````<__^0V````*X`1H8.APV(#(D+B@J+"8P(
MC0>.!H\%1@[``@*""L_.S<S+RLG(Q\8.H`%""P```"@```!8__^13````$(`
M1HL)C`B-!XX&CP5&#M`"=,_.S<S+#J`!````````+````(3__Y%H````A@!&
MB0N*"HL)C`B-!XX&CP5&#M`"`GC/SLW,R\K)#J`!````.````+3__Y'````!
M6`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M@#`P%*S\[-S,O*R<C'Q@Z@`0``
M````+````/#__Y+<````D`!&B@J+"8P(C0>.!H\%1@[8`P*"S\[-S,O*#J`!
M````````.````2#__Y,\```",@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`"
M`P(DS\[-S,O*R<C'Q@Z@`0``````'````5S__Y4X````/`!,C@:/!48.P`)D
MS\X.H`$````X```!?/__E5@```!:`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.
MR`("3,_.S<S+RLG(Q\8.H`$````````X```!N/__E7P```$$`$:&#H<-B`R)
M"XH*BPF,"(T'C@:/!48.T$("]L_.S<S+RLG(Q\8.H`$````````0```!]/__
MED@````&`````````#@```((__^6/````=8`1H8.APV(#(D+B@J+"8P(C0>.
M!H\%1@[@(P,!R,_.S<S+RLG(Q\8.H`$``````!````)$__^7V````"(`````
M````(````EC__Y?L```!(@`"XHX&CP5&#L`"7L_.#J`!````````*````GS_
M_YCP```!@@!,BPF,"(T'C@:/!48.\`(#`6[/SLW,RPZ@`0`````H```"J/__
MFDP```!N`%J.!H\%1@[``G8*S\X.H`%("T@.H`'.SP```````!P```+4__^:
MD````"P`1HX&CP5&#L`"7L_.#J`!````2````O3__YJ@````K`!&A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5*#L`";@K/SLW,R\K)R,?&#J`!1@L"9L_.S<S+RLG(
MQ\8.H`$``````$P```-`__^;!```!D(`1H8.APV(#(D+B@J+"8P(C0>.!H\%
M1@Z(A0("A@K/SLW,R\K)R,?&#J`!1@L#`;X*S\[-S,O*R<C'Q@Z@`4(+````
M,````Y#__Z#\```"A`!&B0N*"HL)C`B-!XX&CP5&#L`"`P)VS\[-S,O*R0Z@
M`0```````#@```/$__^C4````&@`1HH*BPF,"(T'C@:/!48.P`("3@K/SLW,
MR\H.H`%&"T;/SLW,R\H.H`$``````$````0`__^([````?P`1H8.APV(#(D+
MB@J+"8P(C0>.!H\%1@[8`@,!V`K/SLW,R\K)R,?&#J`!0@L`````````````
M.```!$3__Z,X```5T`!8A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`'`Q6PS\[-
MS,O*R<C'Q@Z@`0``````(```!(#__[C,````;`!*C@:/!48.P`("6L_.#J`!
M````````.```!*3__[D8```!3@!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5>#L`"
M`N(*S\[-S,O*R<C'Q@Z@`4(+````-```!.#__[HL```!%@!&B`R)"XH*BPF,
M"(T'C@:/!6X.P`("N`K/SLW,R\K)R`Z@`48+````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#__________P``````````__________\````````````````````!
M`````````M,``````````0````````+>``````````\````````$"```````
M```,````````%[``````````#0```````%*(`````&___O4````````"&```
M```````%````````"]@`````````!@````````+P``````````H````````$
M)@`````````+`````````!@`````````%0````````````````````,`````
M``"ML``````````"````````!4``````````%``````````'`````````!<`
M```````2<``````````'````````$```````````"`````````)P````````
M``D`````````&``````````8````````````````;___^P`````(```!````
M`&____D`````````#@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````K!``````````````````````````````&`8````````8)@``
M`````!A&````````&&8````````8A@```````!BF````````&,8````````8
MY@```````!D&````````&28````````91@```````!EF````````&88`````
M```9I@```````!G&````````&>8````````:!@```````!HF````````&D8`
M```````:9@```````!J&````````&J8````````:Q@```````!KF````````
M&P8````````;)@```````!M&````````&V8````````;A@```````!NF````
M````&\8````````;Y@```````!P&````````'"8````````<1@```````!QF
M````````'(8````````<I@```````!S&````````'.8````````=!@``````
M`!TF````````'48````````=9@```````!V&````````':8````````=Q@``
M`````!WF````````'@8````````>)@```````!Y&````````'F8````````>
MA@```````!ZF````````'L8````````>Y@```````![X````````````````
M`````````````%*(`````````````````````````````!>P````````````
M````````````````````````````````````````````````````````````
M`````````````````````+``_____P````````````!2J@```````%*P````
M``````````````!2L@```````%*V````````4KX```````!3*@```````%+&
M``````````````````!2R@```````%+0``````````````````!5AD=#0SH@
M*$%L<&EN92`Q,"XS+C%?9VET,C`R,3`T,C0I(#$P+C,N,2`R,#(Q,#0R-```
M+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N9'EN86UI
M8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````
M````````````````````````````````````````````````````````````
M```````````+`````0`````````"`````````@`````````"```````````8
M`````````````````````0``````````````$V____8``````````@``````
M``(8`````````A@`````````V`````,```````````````@`````````````
M`!T````+``````````(````````"\`````````+P````````".@````$````
M`@`````````(`````````!@````E`````P`````````"````````"]@`````
M```+V`````````0F`````````````````````0``````````````+0````0`
M`````````@```````!``````````$``````````"<`````,`````````````
M``@`````````&````#<````$`````````$(````````2<````````!)P````
M````!4`````#````$0`````````(`````````!@```!!`````0`````````&
M````````%[`````````7L``````````H`````````````````````@``````
M````````/`````$`````````!@```````!?8````````%]@````````'(```
M``````````````````0`````````(````$<````!``````````8````````>
M^````````![X````````,Y`````````````````````(``````````````!-
M`````0`````````&````````4H@```````!2B``````````B````````````
M`````````@``````````````4P````$``````````@```````%*J````````
M4JH````````^B`````````````````````(``````````````%L````!````
M``````(```````"1-````````)$T`````````-0````````````````````$
M``````````````!I`````0`````````"````````D@@```````"2"```````
M``48````````````````````"```````````````<P````$``````````P``
M`````*OP````````F_``````````$`````````````````````@`````````
M`````'H````!``````````,```````"L`````````)P``````````!``````
M```````````````(``````````````"!````!@`````````#````````K!``
M``````"<$`````````&@````!```````````````"``````````0````B@``
M``$``````````P```````*VP````````G;`````````"4```````````````
M``````@`````````"````(\````!``````````,```````"P`````````*``
M`````````'@````````````````````(``````````````"5````"```````
M```#````````L'@```````"@>````````!!@````````````````````"```
M````````````F@````$`````````,```````````````````H'@`````````
M,0````````````````````$``````````0````$````#````````````````
L`````````````*"I`````````*,````````````````````!````````````
